@@ -40,7 +40,8 @@
 #' @export
 #' 
 pbToDf <- function(pb, templateNames = NULL) {
-    skip <- c('annotations', 'wave', 'contour', 'contWidth', 'sliceData', 'demuxData', 'noise')
+    # skip long data
+    skip <- c('annotations', 'wave', 'contour', 'contWidth', 'sliceData', 'demuxData', 'noise', 'excess', 'energy', 'points')
     good <- FALSE
     fileName <- NULL
     # Case 1: either a PamBinary class, or has the right pieces but not the class
@@ -65,7 +66,7 @@ pbToDf <- function(pb, templateNames = NULL) {
         stop('Input does not look like a PamBinaray output.')
     }
     result <- bind_rows(lapply(justData, function(x) {
-        if('noise' %in% names(x)) {
+        if(all(c('noise', 'nBands') %in% names(x))) {
             tmp <- x[keepIx]
             tmp <- data.frame(list(tmp, octaveBand = 1:x$nBands))
             tmp$noiseMean <- x$noise[1, ]
